@@ -14,7 +14,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Any, Dict, TYPE_CHECKING
 from botocore.exceptions import ClientError as Boto3ClientError
-from mypy_boto3_ec2_instance_connect.type_defs import ClientSendSshPublicKeyResponseTypeDef
+from mypy_boto3_ec2_instance_connect.type_defs import SendSSHPublicKeyResponseTypeDef
 
 
 __all__ = ("EC2InstanceConnectClient",)
@@ -31,14 +31,14 @@ class Exceptions:
 
 class EC2InstanceConnectClient:
     """
-    [EC2InstanceConnect.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.3/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
+    [EC2InstanceConnect.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.3/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -47,14 +47,14 @@ class EC2InstanceConnectClient:
         Params: Dict[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
-    ) -> None:
+    ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.3/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
         """
 
     def send_ssh_public_key(
         self, InstanceId: str, InstanceOSUser: str, SSHPublicKey: str, AvailabilityZone: str
-    ) -> ClientSendSshPublicKeyResponseTypeDef:
+    ) -> SendSSHPublicKeyResponseTypeDef:
         """
-        [Client.send_ssh_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.3/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
+        [Client.send_ssh_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
         """
